@@ -28,6 +28,9 @@ class DesignPytternError(Exception):
     """
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
-        self.message = kwargs.pop('message', '')
+        self.message = kwargs.pop('message', repr(self))
 
         super().__init__(*args, **kwargs)
+
+    def __str__(self) -> str:
+        return self.message
