@@ -1,6 +1,6 @@
 #! /usr/bin/env python3
 
-# SPDX-FileCopyrightText: 2020 Alchemy-Meister
+# SPDX-FileCopyrightText: 2020-2021 Alchemy-Meister
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 
@@ -14,7 +14,7 @@ class Subscriber(ABC):
     """Abstract subscriber. Define the generic ``update`` method."""
 
     @abstractmethod
-    def update(self, *args: Any, **kwargs: Any):
+    def update(self, *args: Any, **kwargs: Any) -> None:
         """
         Abstract update method.
 
